﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Media.Animation;

namespace InitializingAnimations
{
	public partial class DialogControl : UserControl
	{
	    private bool _RunDirectClose;
	    private Point _StartingPosition;
	
		public DialogControl()
		{
			// Required to initialize variables
			InitializeComponent();

            // initialize to Closed
            VisualStateManager.GoToState(this, "Closed", false);
		}
		
        public void ShowDialog(Point startingPosition, int choiceNumber)
        {
            _StartingPosition = startingPosition;
            _RunDirectClose = (choiceNumber == 0);
        
            switch (choiceNumber)
                {
                    case 0:  RunDirectStoryboard(); break;
                    case 1:  RunVsmAndSetFrom(); break;
                    default: return;
                }
        }

        private void RunDirectStoryboard()
        {
            dialogStartLeft.From = dialogEndLeft.To = _StartingPosition.X;
            dialogStartTop.From = dialogEndTop.To = _StartingPosition.Y;

            Storyboard sb = (Resources["ShowDialogStoryboard"] as Storyboard);
            sb.Begin();   
        }

        private void RunVsmAndSetFrom()
        {
            // initialize the Open Storyboard in the VSM
            Storyboard openStoryboard = Utility.FindStoryboard(LayoutRoot, "DialogStates", "Open");
            (openStoryboard.Children[0] as DoubleAnimation).From = _StartingPosition.X;
            (openStoryboard.Children[1] as DoubleAnimation).From = _StartingPosition.Y;

            // initialize th Close Storyboard in the VSM
            Storyboard closeStoryboard = Utility.FindStoryboard(LayoutRoot, "DialogStates", "Closed");
            (closeStoryboard.Children[0] as DoubleAnimation).To = _StartingPosition.X;
            (closeStoryboard.Children[1] as DoubleAnimation).To = _StartingPosition.Y;
            
            VisualStateManager.GoToState(this, "Open", true);
        }

        private void CloseButton_Click(object sender, RoutedEventArgs e)
        {
            if (_RunDirectClose)
            {
                Storyboard sb = (Resources["HideDialogStoryboard"] as Storyboard);
                sb.Begin();   
            }
            else
            {    
                VisualStateManager.GoToState(this, "Closed", true);
            }
        }

        private void LayoutRoot_MouseLeftButtonUp(object sender, System.Windows.Input.MouseButtonEventArgs e)
        {
            e.Handled = true;
        }
	}
}